EvStripe
========

Plugin for taking Stripe payments using EvTransactions.

Usage
-----

When using Stripe all card data is submitted directly to the payment gateway and not via the website's server. This is handled using some JavaScript supplied by Stripe that generates a token that is then submitted to the website's server for processing the payment. So on your payment page you need to include the JS which is done using the `stripejs` element:-

	<?= $this->element('EvStripe.stripejs') ?>

If you want to customise the script for handling the communication between the website and Stripe
then override the `webroot/js/stripe.js` file.

Make sure you also load the Stripe component in your controller so that the Stripe JS is set up with the correct key:-

	$this->loadComponent('EvStripe.Stripe');

An example payment form has been included that can be used directly or just as a guide. This can be found in `View/Elements/payment_form.ctp`. It's important that the form inputs aren't named so that they don't submit card details to the server and that they use the `data-stripe` attributes.

You will need to configure the plugin in `Config/Plugin/ev_transactions.php` and it should look something like:-

	$config = [
		'EvTransactions' => [
			'gateway' => 'EvStripe.Stripe',
			'currency' => 'gbp',
			'stripe' => [
				'live' => [
					'secret_key' => 'to-be-provided-by-client',
					'publishable_key' => 'to-be-provided-by-client'
				],
				'dev' => [
					'secret_key' => 'sk_test_5Z0SK51oEvPlaRkh6wKFJ7Gu',
					'publishable_key' => 'pk_test_oTLrM7uYObyZd3BtBIX61mg1'
				]
			]
		]
	];

When you take payment using EvTransactions' `Transactions::takePayment()` it will return the payment response to determine if successful payment has been taken or not rather than `processReturn()`.

This plugin uses OmniPay.

## Stripe Checkout

Stripe has a JavaScript popover form that can be used for payments. This exists as a basic element at `View/Elements/stripe_checkout.ctp`:

	<?= $this->element('EvStripe.stripe_checkout') ?>

This element is set to output a `<script>` element inside a `<form>` tag which will POST to the page it's on. All the script does is render a `<button>` so you will your own HTML wrappers. The rendered button has the class `stripe-button-el`.

Please note that you do not need to include the other elements (payment_form, stripejs)

You will need to create the "checkout" settings array inside your EvTransactions > Stripe config:

	$config = [
		'EvTransactions' => [
			'gateway' => 'EvStripe.Stripe',
			'currency' => 'gbp',
			'stripe' => [
				'live' => [
					'secret_key' => 'to-be-provided-by-client',
					'publishable_key' => 'to-be-provided-by-client'
				],
				'dev' => [
					'secret_key' => 'sk_test_5Z0SK51oEvPlaRkh6wKFJ7Gu',
					'publishable_key' => 'pk_test_oTLrM7uYObyZd3BtBIX61mg1'
				],
				'checkout' => [
					'escape' => true, // CakePHP general tag escaping (converts "&" to "&amp; etc")
					'data-image' => null,
					'data-name' => null,
					'data-description' => null,
					'data-locale' => null,
					'data-zip-code' => null, // Boolean; set whether you would like Stripe to validate the billing postal code
					'data-billing-address' => null // Boolean; specify whether you would like to collect billing address
				]
			]
		]
	];

The data in here is used to render a Cake HTML Script tag. You can edit the values in the array to your needs, or even add additional ones as specified at https://stripe.com/docs/checkout#integration-simple-options

The ones added here are just for example purposes; none of the `data-` attributes here are mandatory.

For anything that needs to be set on a per-checkout basis, options can be added/overwritten on your checkout page by adding an Options array along with the element:

	<?= $this->element('EvStripe.stripe_checkout', [
		'options' => [
			'data-foo' => 'bar'
		]
	]) ?>
