/* global stripe, $, console */
var defaultPaymentRequestParameters = {
	country: 'GB',
	currency: 'gbp',
	requestPayerName: true,
	requestPayerEmail: true,
	total: buildPaymentRequestTotal(),
};

var paymentRequest = stripe.paymentRequest(defaultPaymentRequestParameters);
var elements = stripe.elements();

var prButton = elements.create('paymentRequestButton', {
	paymentRequest: paymentRequest,
	style: {
		paymentRequestButton: {
			type: 'default', //'default' | 'donate' | 'buy', // default: 'default'
			theme: 'dark', //'dark' | 'light' | 'light-outline', // default: 'dark'
			height: '40px', // default: '40px', the width is always '100%'
		},
	},
});

prButton.on('click', function (ev) {
	paymentRequest.update({total: buildPaymentRequestTotal()});
});

function buildPaymentRequestTotal() {
	var container = document.getElementById('payment-request-button');

	return {
		label: container.getAttribute('data-title'),
		amount: parseInt(container.getAttribute('data-price')),
	};
}

// Check the availability of the Payment Request API first.
paymentRequest.canMakePayment().then(function (result) {
	if (result) {
		prButton.mount('#payment-request-button');
	} else {
		document.getElementById('payment-request-button').style.display = 'none';
	}
});

paymentRequest.on('token', function (ev) {
	// Send the token to your server to charge it!
	var $form = $('.form-checkout');

	var $fetchBody = '';

	if ($form.length === 0) {
		$fetchBody = JSON.stringify({stripeToken: ev.token.id});
	} else {
		$form.append($('<input type="hidden" name="data[stripeToken]">').val(ev.token.id));
		$fetchBody = $form.serializeJSON();
	}

	fetch(window.location.href, {
		method: 'POST',
		body: $fetchBody,
		headers: {
            "Content-Type": "application/json; charset=utf-8",
            "X-Requested-With": "XMLHttpRequest" // This is how CakePHP detirmines it is an AJAX request
        },
        credentials: "include"
	}).then(function (response) {
		if (response.ok) {
			// If it was not a redirect try and parse for JSON to see if it was ok or not 
			response.json().then(function (json) {
				if (json.success) {
					ev.complete('success');
					window.location.href = json.url;
				} else {
					ev.complete('fail');
					window.location.href = json.url;
				}
			})
		} else {
			// Report to the browser that there was an unexpected error
			ev.complete('fail');
			// Reload the page
			window.location.href = response.url;
		}
	}).catch(function(error) {
        ev.complete('fail');
    });
});
